Module dice_command_parser::dice_roll [−][src]
Provides access to the DiceRoll struct.
Structs
This struct represents the information required to calculate the result of a dice roll given the command string. Validating the sanity of each of the parameters is left to the user. e.g. The number of dice to roll could be 0.