Enum dice_command_parser::dice_roll::Operation [−][src]
pub enum Operation {
Addition,
Subtraction,
}Expand description
Represents whether a roll should be added or taken away from the total
Variants
The roll should be added towards the overall total
The roll should be taken away from the overall total