Enum dice_command_parser::dice_roll::RollType [−][src]
pub enum RollType {
WithAdvantage,
WithDisadvantage,
Regular,
}Expand description
Represents whether a roll has advantage, disadvantage, independence, or not.
Variants
The roll has advantage and the highest of the two rolls for a set of dice is taken.
The roll has disadvantage and the lowest of the two rolls for a set of dice is taken.
A regular roll occurs - only one roll needs to occur.