Enum dice_command_parser::error::ParserError [−][src]
pub enum ParserError {
ParseError(String),
InvalidNumberInput(ParseIntError),
Unknown,
}Expand description
Errors that can occur parsing the command input.
Variants
Implies that the string was not in the correct format.
Tuple Fields of ParseError
0: StringOccurs when the numbers provided in the input cannot be turned into i32. This is likely an overflow or underflow error.
Tuple Fields of InvalidNumberInput
Reserved for errors that do not fit into other categories.